@@ -1,11 +1,11 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.002001';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.000000';
 #pod =encoding UTF-8
-#pod  
+#pod
 #pod =head1 SYNOPSIS
-#pod  
+#pod
 #pod Put following into your C<My-Module/dist.ini>:
 #pod
 #pod 	[@Author::MAXHQ]
@@ -18,7 +18,7 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.002001';
 #pod The bundles' behaviour can be altered by the following options:
 #pod
 #pod =for :list
-#pod * C<GatherDir.exclude_match> - a regex specifying which files or directories to 
+#pod * C<GatherDir.exclude_match> - a regex specifying which files or directories to
 #pod   ignore (they are not processed and thus not added to the distribution tarball).
 #pod   This option can be specified several times for different regexes.
 #pod * C<PodWeaver.replacer> - Which replacer to use for POD sections.
@@ -30,7 +30,7 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.002001';
 #pod =head1 OVERVIEW
 #pod
 #pod Currently this plugin bundle is equivalent to:
-#pod 	
+#pod
 #pod 	#
 #pod 	# Files included
 #pod 	#
@@ -41,26 +41,27 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.002001';
 #pod 	prune_directory = ^\.git$
 #pod 	prune_directory = ^\.svn$
 #pod 	prune_directory = ^extlib$
+#pod 	prune_directory = ^local$
 #pod 	prune_directory = ^CVS$
 #pod 	include_dotfiles = 1
-#pod 	
+#pod
 #pod 	[PruneCruft]
 #pod 	[ExecDir]
 #pod 	dir = bin
-#pod 	
+#pod
 #pod 	[ShareDir]
 #pod 	dir = share/dist/My-Module
-#pod 	
+#pod
 #pod 	#
 #pod 	# Conversion and replacements
 #pod 	#
 #pod 	[PkgVersion]
 #pod 	die_on_existing_version = 1
 #pod 	die_on_line_insertion   = 1
-#pod 	
+#pod
 #pod 	[NextRelease]
 #pod 	format = '%-9v %{yyyy-MM-dd}d'
-#pod 	
+#pod
 #pod 	[PreviousVersion::Changelog]
 #pod 	[NextVersion::Semantic]
 #pod 	major = *NEW FEATURES, *API CHANGES
@@ -76,15 +77,24 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.002001';
 #pod 	#
 #pod 	# Prerequisites
 #pod 	#
-#pod 	[AutoPrereqs]
+#pod 	[Prereqs::FromCPANfile]
 #pod 	[Prereqs::AuthorDeps]
-#pod 	[PrereqsClean]
+#pod 	[AutoPrereqs]
 #pod
 #pod 	[Prereqs / MAXHQ]
+#pod 	-phase = runtime
+#pod 	-relationship = requires
+#pod 	Pod::Elemental::Transformer::List = 0.102000
+#pod
+#pod 	[Prereqs / MAXHQ-DEV]
 #pod 	-phase = devlop
 #pod 	-relationship = requires
-#pod 	Pod::Elemental::Transformer::List = 0
-#pod 	Pod::Coverage::TrustPod = 0
+#pod 	Pod::Coverage::TrustPod = 0.100003
+#pod
+#pod 	[RemovePrereqs]
+#pod 	remove = strict
+#pod
+#pod 	[CheckSelfDependency]
 #pod
 #pod 	#
 #pod 	# Auto generation --- distribution files
@@ -114,7 +124,7 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.002001';
 #pod 	[TestRelease]
 #pod 	[ConfirmRelease]
 #pod
-#pod =cut 
+#pod =cut
 
 use Moose;
 
@@ -152,7 +162,7 @@ sub mvp_multivalue_args { return qw(GatherDir.exclude_match) }
 #pod =cut
 sub add_plugins_if_wanted {
 	my ($self, @plugin_specs) = @_;
- 
+
 	my @plugin_specs_filtered = ();
 	foreach my $this_spec (@plugin_specs) {
 		my $moniker = ref $this_spec ? $this_spec->[0] : $this_spec;
@@ -174,7 +184,7 @@ sub add_plugins_if_wanted {
 #
 sub configure {
     my $self = shift;
-	
+
 	# build this array by merging...
 	my @exclude_matches = (
 		# ...the parameter (or an empty ref)
@@ -185,23 +195,23 @@ sub configure {
 			\A[^\/]+\.tar\.gz\Z
 		)
 	);
- 
+
     $self->add_plugins_if_wanted(
 		#
 		# Files included
 		#
 		['GatherDir' => {                 # skip files on top level
 			exclude_match => \@exclude_matches,
-			prune_directory => ['\Aextlib\Z', '\A\.build\Z', '\A\.git\Z', '\A\.svn\Z', '\ACVS\Z'],
+			prune_directory => ['\Aextlib\Z', '\Alocal\Z', '\A\.build\Z', '\A\.git\Z', '\A\.svn\Z', '\ACVS\Z'],
 			include_dotfiles => 1, # needed e.g. for ".devdir"
 		}],
 		'PruneCruft',                     # prune stuff you probably don't want
 
 		['ExecDir' => {                   # install contents of bin/ as executable
 			dir => 'bin',
-		}],		
+		}],
 		'ShareDir::ProjectDistDir',       # include all files in /share/dist/My-Dist
-		
+
 		#
 		# Conversion and replacements
 		#
@@ -224,7 +234,7 @@ sub configure {
 		# Please note that * and ! are mainly there to enforce correct ordering
 		# as CPAN::Changes::Release (used in NextVersion::Semantic) just sorts
 		# groups alphabetically
-		
+
 		# weave your Pod together from configuration and Dist::Zilla
 		# (turns "# ABSTRACT" into POD, processes =method and short lists etc.)
 		# To exclude files from PodWeaver see: http://blogs.perl.org/users/polettix/2011/11/distzilla-podweaver-and-bin.html
@@ -232,25 +242,34 @@ sub configure {
 			config_plugin => '@Author::MAXHQ',
 			replacer      =>
 				$self->payload->{'PodWeaver.replacer'}
-				|| 'replace_with_comment', # replace original POD with comments to preserve line numbering 
-				
+				|| 'replace_with_comment', # replace original POD with comments to preserve line numbering
+
 		}],
 
 		#
 		# Prerequisites
 		#
-		'AutoPrereqs',                    # extract prereqs from your modules
+		'Prereqs::FromCPANfile',          # use prereqs from "cpanfile"
 		'Prereqs::AuthorDeps',            # "adds Dist::Zilla and the result of "dzil
 		                                  # authordeps" to the 'develop' phase prerequisite list"
-		'PrereqsClean',                   # "Cleans up mess from other Prereq modules"
-		['Prereqs' => 'MAXHQ-DEV', {      # special prerequisites (name MAXHQ-DEV 
+		'AutoPrereqs',                    # extract prereqs from your modules
+		# Pod::Elemental::Transformer::List is required because we specify the List plugin in Pod::Weaver::PluginBundle::Author::MAXHQ
+		['Prereqs' => 'MAXHQ', {          # special prerequisites (name MAXHQ
+			'-phase' => 'runtime',        # disambiguates the Prereqs plugin in
+			'-relationship' => 'requires',# case it's also specified in users' dist.ini)
+			'Pod::Elemental::Transformer::List' => '0.102000',
+		}],
+		['Prereqs' => 'MAXHQ-DEV', {      # special prerequisites (name MAXHQ-DEV
 			'-phase' => 'develop',        # disambiguates the Prereqs plugin in
 			'-relationship' => 'requires',# case it's also specified in users' dist.ini)
-			'Pod::Elemental::Transformer::List' => 0, # not automatically installed with Dist::Zilla
-			'Pod::Coverage::TrustPod' => 0,           # not automatically installed with Dist::Zilla
+			'Pod::Coverage::TrustPod' => '0.100003', # missing in Dist::Zilla prerequisites
 		}],
-		
-		
+		['RemovePrereqs' => {
+			'remove' => [ qw( strict ) ],
+		}],
+
+		'CheckSelfDependency',            # Make sure no packages of this dist ended up in the prerequisites list
+
 		#
 		# Auto generation --- distribution files
 		#
@@ -264,7 +283,7 @@ sub configure {
 		# Auto generation --- tests
 		#
 		'Test::Inline',                   # generate .t files from inline test code (POD)
-		
+
 		# auto-generate various tests
 		'ExtraTests',
 		'Test::Perl::Critic',
@@ -285,32 +304,32 @@ sub configure {
 		'ConfirmRelease',                 # ask for confirmation before releasing
     );
 }
- 
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
 {
 	package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
 	# ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '1.002001';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.000000';
 use Moose;
 	use namespace::autoclean;
 
 	with 'Dist::Zilla::Role::ShareDir';
 
  	use File::Spec;
- 
+
 	has dir => (
 		is	 => 'ro',
 		isa	=> 'Str',
 		lazy_build => 1,
 	);
-	
+
 	sub _build_dir {
 		my ($self) = @_;
 		return File::Spec->catfile('share', 'dist', $self->zilla->name),
 	}
-	 
+
 	sub find_files {
 		my ($self) = @_;
 		my $dir = $self->dir;
@@ -319,14 +338,14 @@ use Moose;
 				@{ $self->zilla->files }
 		];
 	}
-	 
+
 	sub share_dir_map {
 		my ($self) = @_;
 		my $files = $self->find_files;
 		return unless @$files;
 		return { dist => $self->dir };
 	}
-	 
+
 	__PACKAGE__->meta->make_immutable;
 }
 
@@ -340,7 +359,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 1.002001
+version 2.000000
 
 =head1 SYNOPSIS
 
@@ -359,7 +378,7 @@ The bundles' behaviour can be altered by the following options:
 
 =item *
 
-C<GatherDir.exclude_match> - a regex specifying which files or directories to  ignore (they are not processed and thus not added to the distribution tarball). This option can be specified several times for different regexes.
+C<GatherDir.exclude_match> - a regex specifying which files or directories to ignore (they are not processed and thus not added to the distribution tarball). This option can be specified several times for different regexes.
 
 =item *
 
@@ -385,26 +404,27 @@ Currently this plugin bundle is equivalent to:
 	prune_directory = ^\.git$
 	prune_directory = ^\.svn$
 	prune_directory = ^extlib$
+	prune_directory = ^local$
 	prune_directory = ^CVS$
 	include_dotfiles = 1
-	
+
 	[PruneCruft]
 	[ExecDir]
 	dir = bin
-	
+
 	[ShareDir]
 	dir = share/dist/My-Module
-	
+
 	#
 	# Conversion and replacements
 	#
 	[PkgVersion]
 	die_on_existing_version = 1
 	die_on_line_insertion   = 1
-	
+
 	[NextRelease]
 	format = '%-9v %{yyyy-MM-dd}d'
-	
+
 	[PreviousVersion::Changelog]
 	[NextVersion::Semantic]
 	major = *NEW FEATURES, *API CHANGES
@@ -420,15 +440,24 @@ Currently this plugin bundle is equivalent to:
 	#
 	# Prerequisites
 	#
-	[AutoPrereqs]
+	[Prereqs::FromCPANfile]
 	[Prereqs::AuthorDeps]
-	[PrereqsClean]
+	[AutoPrereqs]
 
 	[Prereqs / MAXHQ]
+	-phase = runtime
+	-relationship = requires
+	Pod::Elemental::Transformer::List = 0.102000
+
+	[Prereqs / MAXHQ-DEV]
 	-phase = devlop
 	-relationship = requires
-	Pod::Elemental::Transformer::List = 0
-	Pod::Coverage::TrustPod = 0
+	Pod::Coverage::TrustPod = 0.100003
+
+	[RemovePrereqs]
+	remove = strict
+
+	[CheckSelfDependency]
 
 	#
 	# Auto generation --- distribution files
@@ -482,7 +511,7 @@ Jens Berthold <jens.berthold@jebecs.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jens Berthold.
+This software is copyright (c) 2016 by Jens Berthold.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
